@@ -26,7 +26,7 @@ fn example(c: Common)
 
 	fg.axes2d()
 	.set_size(0.75, 1.0)
-	.set_title("Example Plot", &[])
+	.set_title("Example Plot fg1.1", &[])
 	.set_x_ticks(Some((Fix(1.0), 1)), &[Mirror(false)], &[])
 	.set_y_ticks(Some((Fix(1.0), 1)), &[Mirror(false)], &[])
 	.set_legend(Graph(1.0), Graph(0.5), &[Placement(AlignLeft, AlignCenter)], &[TextAlign(AlignRight)])
@@ -56,7 +56,7 @@ fn example(c: Common)
 	fg.axes2d()
 	.set_pos_grid(2, 2, 0)
 	.lines(x, y1, &[Caption("Lines"), LineWidth(3.0), Color("violet")])
-	.set_title("Plot1", &[]);
+	.set_title("Plot1 fg1.2", &[]);
 
 	fg.axes2d()
 	.set_pos_grid(2, 1, 1)
@@ -76,7 +76,7 @@ fn example(c: Common)
 	.set_size(0.3, 0.6)
 	.set_aspect_ratio(Fix(1.0))
 	.points(x, y2, &[Caption("Points"), PointSymbol('T'), Color("#ffaa77")])
-	.set_title("Inset", &[]);
+	.set_title("Inset fg1.3", &[]);
 
 	c.show(&mut fg, "fg1.3.gnuplot");
 
@@ -86,7 +86,8 @@ fn example(c: Common)
 	fg.axes2d()
 	.lines(x, y1, &[Caption("Lines"), LineWidth(3.0), Color("violet")])
 	.set_y_range(Fix(-30.0), Auto)
-	.set_y_label("This axis is manually scaled on the low end", &[]);
+	.set_y_label("This axis is manually scaled on the low end", &[])
+	.set_title("Range fg1.4", &[]);
 
 	c.show(&mut fg, "fg1.4.gnuplot");
 
@@ -96,7 +97,7 @@ fn example(c: Common)
 	fg.axes2d()
 	.x_error_lines(x, y1, x_err, &[LineWidth(2.0), PointSymbol('O'), Color("red")])
 	.y_error_lines(x, y2, y_err, &[LineWidth(2.0), PointSymbol('S'), Color("blue")])
-	.set_title("Errors", &[]);
+	.set_title("Errors fg1.5", &[]);
 
 	c.show(&mut fg, "fg1.5.gnuplot");
 
@@ -112,7 +113,7 @@ fn example(c: Common)
 	.lines(x, y1, &[Color("black"), LineWidth(2.0), LineStyle(Dash), Caption("A")])
 	.lines(x, y2, &[Color("black"), LineWidth(2.0), Caption("C")])
 	.lines(x, y3, &[Color("black"), LineWidth(2.0), LineStyle(DotDotDash), Caption("B")])
-	.set_title("Fill and legend", &[])
+	.set_title("Fill and legend fg1.6", &[])
 	.set_legend(Graph(0.5), Graph(-0.2), &[Horizontal, Placement(AlignCenter, AlignTop), Title("Legend Title")], &[TextAlign(AlignRight)]);
 
 	c.show(&mut fg, "fg1.6.gnuplot");
@@ -128,7 +129,7 @@ fn example(c: Common)
 	.lines_points(x, y3, &[Caption("x - 4"), PointSymbol('O'), Color("black"), LineStyle(SmallDot)])
 	.set_x_label("X Label", &[Font("Arial", 24.0), TextColor("red"), Rotate(45.0)])
 	.set_y_label("Y Label", &[Rotate(0.0)])
-	.set_title("Goings nuts with the formatting", &[Font("Times", 24.0), TextOffset(-10.0, 0.5)])
+	.set_title("Goings nuts with the formatting fg1.7", &[Font("Times", 24.0), TextOffset(-10.0, 0.5)])
 	.label("Intersection", Axis(2.208), Axis(-1.791), &[MarkerSymbol('*'), TextAlign(AlignCenter), TextOffset(0.0, -1.0), MarkerColor("red"), MarkerSize(2.0)]);
 
 	c.show(&mut fg, "fg1.7.gnuplot");
