@@ -147,6 +147,7 @@ pub fn write_out_label_options<T: PlotWriter + Writer>(label_type: LabelType, op
 	}
 }
 
+#[derive(Copy, Clone)]
 pub enum TickAxis
 {
 	XTickAxis,
@@ -250,6 +251,8 @@ pub struct AxisData
 	pub axis: TickAxis,
 	pub min: AutoOption<f64>,
 	pub max: AutoOption<f64>,
+	pub reverse: bool,
+	pub grid: bool,
 }
 
 impl AxisData
@@ -264,6 +267,8 @@ impl AxisData
 			axis: axis,
 			min: Auto,
 			max: Auto,
+			reverse: false,
+			grid: false,
 		}
 	}
 
@@ -319,7 +324,14 @@ impl AxisData
 			Fix(v) => write!(w, "{:.12e}", v),
 			Auto => w.write_str("*")
 		};
-		w.write_str("]\n");
+		if self.reverse
+		{
+			w.write_str("] reverse\n");
+		}
+		else
+		{
+			w.write_str("]\n");
+		}
 
 		w.write_all(&self.ticks_buf[..]);
 	}
@@ -435,6 +447,13 @@ impl AxisData
 		}
 
 		write!(&mut *c, " scale {:.12e},{:.12e}", minor_scale, major_scale);
+
+		first_opt!{tick_options,
+			Format(f) =>
+			{
+				write!(&mut *c, r#" format "{}""#, f);
+			}
+		}
 	}
 
 	pub fn set_ticks(&mut self, tick_placement: Option<(AutoOption<f64>, u32)>, tick_options: &[TickOption], label_options: &[LabelOption])
@@ -490,11 +509,22 @@ impl AxisData
 	{
 		self.log_base = base;
 	}
+
+	pub fn set_reverse(&mut self, reverse: bool)
+	{
+		self.reverse = reverse;
+	}
+
+	pub fn set_grid(&mut self, show: bool)
+	{
+		self.grid = show;
+	}
 }
 
 pub struct AxesCommonData
 {
 	pub commands: Vec<u8>,
+	pub grid_options: Vec<u8>,
 	pub elems: Vec<PlotElement>,
 	pub grid_rows: u32,
 	pub grid_cols: u32,
@@ -540,6 +570,7 @@ impl AxesCommonData
 		AxesCommonData
 		{
 			commands: vec![],
+			grid_options: vec![],
 			elems: Vec::new(),
 			grid_rows: 0,
 			grid_cols: 0,
@@ -550,6 +581,21 @@ impl AxesCommonData
 		}
 	}
 
+	pub fn write_grid_options(&self, c: &mut Writer, axes: &[TickAxis])
+	{
+		if !axes.is_empty()
+		{
+			c.write_str("set grid ");
+			for axis in axes
+			{
+				c.write_str(axis.to_tick_str());
+				c.write_str(" ");
+			}
+			c.write_all(&self.grid_options);
+			c.write_str("\n");
+		}
+	}
+
 	pub fn write_line_options(c: &mut Writer, options: &[PlotOption])
 	{
 		let mut found = false;
@@ -907,6 +953,8 @@ impl AxesCommonData
 
 		c.write_str("\n");
 	}
+
+
 }
 
 #[doc(hidden)]
@@ -1137,6 +1185,24 @@ pub trait AxesCommon : AxesCommonPrivate
 		self
 	}
 
+	/// Sets X axis to reverse.
+	/// # Arguments
+	/// * `reverse` - Boolean, true to reverse axis, false will not reverse
+	fn set_x_reverse<'l>(&'l mut self, reverse: bool) -> &'l mut Self
+	{
+		self.get_common_data_mut().x_axis.set_reverse(reverse);
+		self
+	}
+
+	/// Sets Y axis to reverse.
+	/// # Arguments
+	/// * `reverse` - Boolean, true to reverse axis, false will not reverse
+	fn set_y_reverse<'l>(&'l mut self, reverse: bool) -> &'l mut Self
+	{
+		self.get_common_data_mut().y_axis.set_reverse(reverse);
+		self
+	}
+
 	/// Set the range of values for the color bar axis.
 	///
 	/// # Arguments
@@ -1178,6 +1244,62 @@ pub trait AxesCommon : AxesCommonPrivate
 		self
 	}
 
+	/// Shows the grid on the X axis.
+	///
+	/// # Arguments
+	/// * `show` - Whether to show the grid.
+	fn set_x_grid<'l>(&'l mut self, show: bool) -> &'l mut Self
+	{
+		self.get_common_data_mut().x_axis.set_grid(show);
+		self
+	}
+
+	/// Shows the grid on the Y axis.
+	///
+	/// # Arguments
+	/// * `show` - Whether to show the grid.
+	fn set_y_grid<'l>(&'l mut self, show: bool) -> &'l mut Self
+	{
+		self.get_common_data_mut().y_axis.set_grid(show);
+		self
+	}
+
+	/// Shows the grid on the color bar axis.
+	///
+	/// # Arguments
+	/// * `show` - Whether to show the grid.
+	fn set_cb_grid<'l>(&'l mut self, show: bool) -> &'l mut Self
+	{
+		self.get_common_data_mut().cb_axis.set_grid(show);
+		self
+	}
+
+	/// Set the grid options.
+	///
+	/// # Arguments
+	/// * `front` - Whether the grid should be in the front of the plot elements or behind them.
+	/// * `options` - Styling options of the grid. Relevant options are:
+	///      * `Color` - Specifies the color of the grid lines
+	///      * `LineStyle` - Specifies the style of the grid lines
+	///      * `LineWidth` - Specifies the width of the grid lines
+	fn set_grid_options<'l>(&'l mut self, front: bool, options: &[PlotOption]) -> &'l mut Self
+	{
+		{
+			let c = &mut self.get_common_data_mut().grid_options as &mut Writer;
+			if front
+			{
+				c.write_str("front ");
+			}
+			else
+			{
+				c.write_str("back ");
+			}
+			AxesCommonData::write_line_options(c, options);
+			AxesCommonData::write_color_options(c, options, None);
+		}
+		self
+	}
+
 	/// Sets the palette used for 3D surface and image plots
 	///
 	/// # Arguments
